CompactEpgReminderStatus enum

Inheritance
Available extensions

Values

scheduled → const CompactEpgReminderStatus
const CompactEpgReminderStatus('scheduled')
unchanged → const CompactEpgReminderStatus
const CompactEpgReminderStatus('unchanged')
unresolved → const CompactEpgReminderStatus
const CompactEpgReminderStatus('unresolved')
skippedPastNotification → const CompactEpgReminderStatus
const CompactEpgReminderStatus('skipped_past_notification')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stableId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CompactEpgReminderStatus>
A constant List of the values in this enum, in order of their declaration.