CompactEpgSnapshotStore class abstract

Implementers

Constructors

CompactEpgSnapshotStore()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteSnapshot() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readSnapshot() → Future<String?>
toString() → String
A string representation of this object.
inherited
writeSnapshot(String payload) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited