DistributedEpgStableValueRejectionCode enum

Inheritance
  • Object
  • Enum
  • DistributedEpgStableValueRejectionCode
Available extensions

Values

empty → const DistributedEpgStableValueRejectionCode
const DistributedEpgStableValueRejectionCode('empty')
urlValue → const DistributedEpgStableValueRejectionCode
const DistributedEpgStableValueRejectionCode('url_value')
localPathValue → const DistributedEpgStableValueRejectionCode
const DistributedEpgStableValueRejectionCode('local_path_value')
localIpValue → const DistributedEpgStableValueRejectionCode
const DistributedEpgStableValueRejectionCode('local_ip_value')
credentialLikeValue → const DistributedEpgStableValueRejectionCode
const DistributedEpgStableValueRejectionCode('credential_like_value')
invalidStableId → const DistributedEpgStableValueRejectionCode
const DistributedEpgStableValueRejectionCode('invalid_stable_id')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stableId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DistributedEpgStableValueRejectionCode>
A constant List of the values in this enum, in order of their declaration.