EpgRefreshResult class

Constructors

EpgRefreshResult({required EpgRefreshStatus status, required int replacedProgrammeCount, required int retainedProgrammeCount})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
replacedProgrammeCount → int
final
retainedProgrammeCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → EpgRefreshStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited