IntelligentEpgTriggerEngine class
Constructors
- IntelligentEpgTriggerEngine()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
select(
{required CompactEpgWindow window, required IntelligentEpgSignals signals, required IntelligentEpgNotificationPolicy policy, required DateTime now, Iterable< EpgNotificationReceipt> deliveryReceipts = const []}) → List<IntelligentEpgTrigger> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited