NativeXmltvParseStats class

Constructors

NativeXmltvParseStats({required int programmeCount, required int skippedProgrammeCount, required bool truncated})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
programmeCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippedProgrammeCount → int
final
truncated → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited