CompactEpgWindowEntry class
One channel's programmes intersecting a GuideWindowQuery's time range, in start-time order.
Constructors
-
CompactEpgWindowEntry({required String channelId, required String channelName, required List<
CompactEpgProgram> programs, List<CompactEpgGap> gaps = const [], String? channelNumber, CompactEpgSourceRef? sourceRef}) -
const
Properties
- channelId → String
-
final
- channelName → String
-
final
- channelNumber → String?
-
final
-
gaps
→ List<
CompactEpgGap> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
programs
→ List<
CompactEpgProgram> -
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceRef → CompactEpgSourceRef?
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited