DistributedEpgSyncRequest class

Constructors

DistributedEpgSyncRequest({required DistributedEpgStableValue requestId, required CompactEpgSourceRef sourceRef, required DateTime requestedAt, required DateTime windowStart, required DateTime windowEnd, required Iterable<String> channelIds, required DistributedEpgTaskKind taskKind, required DistributedEpgPayloadFormat payloadFormat, required DistributedEpgTransferMode transferMode, String schemaVersion = kDistributedEpgWorkerSchemaVersion, int protocolVersion = kDistributedEpgWorkerProtocolVersion})

Properties

channelIds → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
payloadFormat → DistributedEpgPayloadFormat
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
protocolVersion → int
final
requestedAt → DateTime
final
requestId → DistributedEpgStableValue
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion → String
final
sourceRef → CompactEpgSourceRef
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
taskKind → DistributedEpgTaskKind
final
transferMode → DistributedEpgTransferMode
final
window → Duration
no setter
windowEnd → DateTime
final
windowStart → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited